wizards Package
===============

:mod:`wizards` Package
----------------------

.. automodule:: stoqlib.gui.wizards
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`abstractwizard` Module
----------------------------

.. automodule:: stoqlib.gui.wizards.abstractwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`consignmentwizard` Module
-------------------------------

.. automodule:: stoqlib.gui.wizards.consignmentwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loanwizard` Module
------------------------

.. automodule:: stoqlib.gui.wizards.loanwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`personwizard` Module
--------------------------

.. automodule:: stoqlib.gui.wizards.personwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`productionwizard` Module
------------------------------

.. automodule:: stoqlib.gui.wizards.productionwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchasefinishwizard` Module
----------------------------------

.. automodule:: stoqlib.gui.wizards.purchasefinishwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchasequotewizard` Module
---------------------------------

.. automodule:: stoqlib.gui.wizards.purchasequotewizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchasewizard` Module
----------------------------

.. automodule:: stoqlib.gui.wizards.purchasewizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`receivingwizard` Module
-----------------------------

.. automodule:: stoqlib.gui.wizards.receivingwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`renegotiationwizard` Module
---------------------------------

.. automodule:: stoqlib.gui.wizards.renegotiationwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`salequotewizard` Module
-----------------------------

.. automodule:: stoqlib.gui.wizards.salequotewizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`salereturnwizard` Module
------------------------------

.. automodule:: stoqlib.gui.wizards.salereturnwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`salewizard` Module
------------------------

.. automodule:: stoqlib.gui.wizards.salewizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockdecreasewizard` Module
---------------------------------

.. automodule:: stoqlib.gui.wizards.stockdecreasewizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stocktransferwizard` Module
---------------------------------

.. automodule:: stoqlib.gui.wizards.stocktransferwizard
    :members:
    :undoc-members:
    :show-inheritance:

